﻿<#
SAMPLE CODE NOTICE

THIS SAMPLE CODE IS MADE AVAILABLE AS IS.  MICROSOFT MAKES NO WARRANTIES, WHETHER EXPRESS OR IMPLIED, 
OF FITNESS FOR A PARTICULAR PURPOSE, OF ACCURACY OR COMPLETENESS OF RESPONSES, OF RESULTS, OR CONDITIONS OF MERCHANTABILITY.  
THE ENTIRE RISK OF THE USE OR THE RESULTS FROM THE USE OF THIS SAMPLE CODE REMAINS WITH THE USER.  
NO TECHNICAL SUPPORT IS PROVIDED.  YOU MAY NOT DISTRIBUTE THIS CODE UNLESS YOU HAVE A LICENSE AGREEMENT WITH MICROSOFT THAT ALLOWS YOU TO DO SO.
#>

param (
	$AosWebSiteName = 'AosService'
)

$ErrorActionPreference = 'Stop'

function Copy-PackageContents(
    [ValidateNotNullOrEmpty()]
    [string]$sourceFolder = $(Throw 'sourceFolder parameter required'),

    [ValidateNotNullOrEmpty()]
    [string]$destinationParentFolder = $(Throw 'destinationParentFolder parameter required'))
{
    # Ensure source and webroot paths exist.
    if(-not(Test-Path $sourceFolder)) { throw "Source folder does not exist." }
    if(-not(Test-Path $destinationParentFolder)) { throw "Web root folder does not exist." }

    # Copy payment connector web artifacts --> <webroot>\Connectors\
    Log-TimedMessage 'Trying to copy the payment connector web artifacts to AOS.'
    $webArtifactsSourcePath = Join-Path $sourceFolder 'WebArtifacts'

    if(Test-Path $webArtifactsSourcePath)
    {
        Copy-Files $webArtifactsSourcePath (Join-Path $destinationParentFolder 'Connectors')
    }

    # Copy payment connector assemblies to <AOSPackageLocalDir>\Bin\Connectors\ and <webroot>\Bin
    Log-TimedMessage 'Trying to copy the payment connector assemblies to AOS.'
    $assemblySourcePath = Join-Path $sourceFolder 'Assemblies'
    
    if(Test-Path $assemblySourcePath)
    {
        $aosPackageDir = Join-Path (Split-Path -Parent $destinationParentFolder) 'PackagesLocalDirectory\Bin\Connectors'

        Copy-Files $assemblySourcePath $aosPackageDir
		Copy-Files $assemblySourcePath (Join-Path $destinationParentFolder 'Bin')
    }
}

try
{
    $ScriptDir = Split-Path -parent $MyInvocation.MyCommand.Path
    . (Join-Path $ScriptDir 'Common-Configuration.ps1')
    . (Join-Path $ScriptDir 'Common-Web.ps1')

    Log-TimedMessage 'Trying to get the AOS web site root directory.'
    $webroot = (Get-WebSiteSafe -Name $AosWebSiteName).PhysicalPath

    if([string]::IsNullOrWhiteSpace($webroot))
    {
        throw 'Failed to find the website root directory of AOS Service website.'
    }

    Log-TimedMessage ('Found the AOS web site root directory - {0}.' -f $webroot)

    Log-TimedMessage 'Trying to get the package source directory.'
    $sourceFolder = Join-Path (Split-Path -Parent $ScriptDir) 'Code'
    Log-TimedMessage ('Found package source directory - {0}.' -f $sourceFolder)

    Copy-PackageContents -sourceFolder $sourceFolder -destinationParentFolder $webroot

    Log-TimedMessage 'Finished copying payment connector files successfully.'
}
catch
{
    throw ($global:error[0] | format-list * -f | Out-String)
}